package com.cmvr.ti.service;

import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.IService;
import com.cmvr.ti.model.domain.TiVehicleFunction;
import com.cmvr.ti.model.vo.TiVehicleFunctionVO;

import java.util.List;

/**
 * 车辆功能Service接口
 */
public interface ITiVehicleFunctionService extends IService<TiVehicleFunction> {
    /**
     * 查询车辆功能
     *
     * @param id 车辆功能主键
     * @return 车辆功能
     */
    public TiVehicleFunction selectTiVehicleFunctionById(Long id);

    /**
     * 查询车辆功能
     *
     * @param id 车辆功能主键
     * @return 车辆功能
     */
    public JSONObject selectTiVehicleFunctionDetailById(Long id);

    public List<TiVehicleFunction> queryByIds(List<Long> ids);

    /**
     * 查询车辆功能列表
     *
     * @param tiVehicleFunctionVO 车辆功能
     * @return 列表
     */
    public List<TiVehicleFunction> selectTiVehicleFunctionList(TiVehicleFunctionVO tiVehicleFunctionVO);

    /**
     * 新增车辆功能
     *
     * @param tiVehicleFunction 车辆功能
     * @return 结果
     */
    public int insertTiVehicleFunction(TiVehicleFunction tiVehicleFunction);

    /**
     * 修改车辆功能
     *
     * @param tiVehicleFunction 车辆功能
     * @return 结果
     */
    public int updateTiVehicleFunction(TiVehicleFunction tiVehicleFunction);

    /**
     * 批量删除车辆功能
     *
     * @param ids 需要删除的车辆功能主键集合
     * @return 结果
     */
    public int deleteTiVehicleFunctionByIds(Long[] ids);
}
